| Safe Haskell | Safe |
|---|---|
| Language | Haskell2010 |
Data.Conduit.Tar.Types
Description
Module contains all the types necessary for tarball processing.
- data Header = Header {
- headerOffset :: !FileOffset
- headerPayloadOffset :: !FileOffset
- headerFileNameSuffix :: !ShortByteString
- headerFileMode :: !CMode
- headerOwnerId :: !UserID
- headerGroupId :: !GroupID
- headerPayloadSize :: !FileOffset
- headerTime :: !EpochTime
- headerLinkIndicator :: !Word8
- headerLinkName :: !ShortByteString
- headerMagicVersion :: !ShortByteString
- headerOwnerName :: !ShortByteString
- headerGroupName :: !ShortByteString
- headerDeviceMajor :: !DeviceID
- headerDeviceMinor :: !DeviceID
- headerFileNamePrefix :: !ShortByteString
- data TarChunk
- data TarException
- data TarCreateException
- data FileType
- data FileInfo = FileInfo {
- filePath :: !ByteString
- fileUserId :: !UserID
- fileUserName :: !ByteString
- fileGroupId :: !GroupID
- fileGroupName :: !ByteString
- fileMode :: !FileMode
- fileSize :: !FileOffset
- fileType :: !FileType
- fileModTime :: !EpochTime
- type FileOffset = COff
- type ByteCount = CSize
- type UserID = CUid
- type GroupID = CGid
- type DeviceID = CDev
- type EpochTime = CTime
Documentation
Constructors
Constructors
| ChunkHeader Header | |
| ChunkPayload !FileOffset !ByteString | |
| ChunkException TarException |
data TarException Source #
This the the exception type that is used in this module.
More constructors are susceptible to be added without bumping the major version of this module.
Constructors
Instances
data TarCreateException Source #
Constructors
| FileNameTooLong !FileInfo | |
| TarCreationError !String |
Instances
Constructors
| FileInfo | |
Fields
| |
type FileOffset = COff #